# This is a single package containing the beid-middleware, including the
# libraries as well as the firefox plugin used to register the libraries
# with firefox. This enables the use of Belgian eID, for signing and
# authentication for websites such as http://taxonweb.be . I put this all
# in one package, because this is always used together, and nothing else
# requires these files. This new version supersedes the old beid packages.

%define realname eid-mw
%define relsuffix tcm227-258906

Name:		beid-middleware
Summary:	Application to read information from the Belgian e-ID card
Version:	4.1.2
Release:	%mkrel 1
# The original parts are under the "eID Toolkit Software License",
# which by my reading is BSD-like; it's basically the BSD in stronger
# legal language with some added gumph about liability etc. It also
# contains bits of OpenSC (which is LGPLv2+) and OpenSSL (which is
# BSD). - AdamW 2008/09
# Looking at the unofficial link ( http://code.google.com/p/eid-mw ) and
# at the license file inside the svn tree, it seems that it's now released
# as LGPLv3 - alien 2011
License:	LGPLv3
Group:		Security
URL:		http://eid.belgium.be/
Source0:	http://eid.belgium.be/nl/binaries/%{realname}-%{version}-v%{version}.tar_%{relsuffix}.gz
BuildRequires:	gtk2-devel
BuildRequires:	xerces-c-devel
BuildRequires:	pcsc-lite-devel
BuildRequires:	java
BuildRequires:	swig
BuildRequires:	subversion
BuildRequires:	zip
Requires:	pcsc-lite
Obsoletes:	beid < 4.0.0
Obsoletes:	%{_lib}beid2 < 4.0.0
Obsoletes:	%{_lib}beidcomm0 < 4.0.0
Obsoletes:	%{_lib}beidcommon0 < 4.0.0
Obsoletes:	%{_lib}beidgui1 < 4.0.0
Obsoletes:	%{_lib}beidlibopensc2 < 4.0.0
Obsoletes:	%{_lib}beidpcsclite2 < 4.0.0
Obsoletes:	%{_lib}beidpkcs11_2 < 4.0.0
# Suggesting the goverment supplied readers device drivers.
Recommends:	acr38u
Recommends:	ccid

%description
This application allows the user to read out any information from a
Belgian electronic ID card, by using libbeid and libbeidlibopensc to
read the data from the card and parse it. Both identity information 
and information about the stored cryptographic keys can be read in a
user-friendly manner, and can easily be printed out or stored for 
later review.

The application verifies the signature of the identity information,
checks whether it was signed by a government-issued key, and 
optionally checks the certificate against the government's Certificate
Revocation List (CRL) and/or by using the Online Certificate Status
Protocol (OCSP) against the government's servers.

%prep
%setup -q -n %{realname}-%{version}-v%{version}

%build
%configure2_5x
%make
%make xpipackage

%install
%makeinstall_std
# remove static libraries
rm -f %{buildroot}%{_libdir}/*.{la,a}
# remove development libraries
rm -f %{buildroot}%{_libdir}/libbeid*.so
# remove contents of the xpi
rm -rf %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be
# install the xpi itself
install -D -m 755 plugins_tools/xpi/src/belgiumeid.xpi %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi

%find_lang about-eid-mw

%files -f about-eid-mw.lang
%defattr(-, root, root, 0755)
%{_libdir}/libbeid*
%{_libexecdir}/beid-*
%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi
%{_bindir}/about-eid-mw
%{_datadir}/applications/about-eid-mw.desktop


%changelog
* Mon Jul 06 2015 alien <alien> 4.1.2-1.mga4
+ Revision: 852143
- Update to version 4.1.2 (mga#16228)

* Mon Oct 21 2013 umeabot <umeabot> 4.0.4-2.mga4
+ Revision: 539295
- Mageia 4 Mass Rebuild

* Sat Oct 05 2013 alien <alien> 4.0.4-1.mga4
+ Revision: 491810
- Fix building with newer autotools
- package into a .xpi
- Update to new version
- also package the helper tools
- Suggest also ccid
- Switch to upstream release

* Fri Jan 11 2013 umeabot <umeabot> 4.0.0.r929-7.mga3
+ Revision: 346891
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 03 2012 malo <malo> 4.0.0.r929-6.mga3
+ Revision: 302582
- update RPM group

* Sun Aug 19 2012 sander85 <sander85> 4.0.0.r929-5.mga3
+ Revision: 282154
- Fix build with gcc 4.7

  + luigiwalser <luigiwalser>
    - rebuild for libffi

* Mon Sep 19 2011 fwang <fwang> 4.0.0.r929-4.mga2
+ Revision: 145282
- rebuild for new libpng

  + alien <alien>
    - Fix patch to -P1
    - Fix xpi for FF5

* Thu Jun 23 2011 alien <alien> 4.0.0.r929-2.mga2
+ Revision: 112561
- Fix missing obsoletes

* Thu Jun 16 2011 alien <alien> 4.0.0.r929-1.mga2
+ Revision: 108311
- Remove old beidgui references
- Remove development libraries
- Add packaging explanation comment regarding not splitting up the package
- Fix a library linking issue
- Remove static libraries
- imported package beid-middleware

